;********************************************************************************
;* TEST BUS I2C amb I/O PCA9555        versio 3           Lleonard Garcia i Llop*
;********************************************************************************
; 1.-Per estalviar energia es pot col_locar un led bicolor en lloc del motor.
; 2.-BRIDGE MOTORS (4 semibridges amb SN754410NE)
;    Bridge= pont  Es una connexio en que de forma de H (el trem vertical
;    de la dreta, el tram mig horitzontal i el tram vertical de l'esquerra).
;    El Semibridge_a, en funcio d'un 0 o 1, connecta a + o - el born_a del motor.
;    El Semibridge_b, en funcio d'un 0 o 1, connecta a + o - el born_b del motor.
;    Semi_bridge_a Semi_bridge_M1b Motor                    Leds
;        0 (-)         0 (-)       ATURAT                   APAGAT
;        1 (+)         0 (-)   CCWS (gira en sentit invers) Verd
;        0 (-)         1 (+)       CWS (gira envant)        Vermell
;        1 (+)         1 (+)       ATURAT                   APAGAT
; 3.-El sistema te un defecte. Si gira envant i immediatament es dona instruccio
;    de girar enrera, te el mateix efecte que un curtcircuit. Es recomana afegir
;    un breu retard i fer que el temps amortitzi l'energia acumulada en el motor
;    en moviment.
; 4.-CIRCUIT IMPRES QUE UTILITZA PICAXE 14M2
;                  **********************
;              +V  * 1               14 *  GND
;          SI /C.5 * 2               13 *  B.0 /SO  bridge M2 (canviar jumper)
;  bridge M1   C.4 * 3               12 *  B.1      bridge M2
;  boto_PUJAR  C.3 * 4               11 *  B.2      SENSOR_INPERIOR
;  bridge M1   C.2 * 5               10 *  B.3      SENSOR_SUPERIOR / I2C_SCL
;  boto_BAIXAR C.1 * 6                9 *  B.4      LED_SUPERIOR / I2C_SDA
;  IR_TSOP4838 C.0 * 7                8 *  B.5      LED_INFERIOR
;                  **********************
pause 1000; permet programacio segura durant 1 segon despres de connectar
;********************************************************************************
;********************************************************************************
;CONFIGURACIONS DEL HARDWARE
;setint %00000000,%00000000   ; Configuracio de les interrupcions.
let dirsC=%00010100           ; Definicions del port_C (1=sortida 0=entrada).
let dirsB=%00110011           ; Definicions del port_B (1=sortida 0=entrada).
symbol bridge_M1a=C.2   	; SORTIDA.Semi-bridge_a del motor_M1.
symbol bridge_M1b=C.4   	; SORTIDA.Semi-bridge_b del motor_M1.
symbol bridge_M2a=B.0   	; SORTIDA.Semi-bridge_a del motor_M2.
symbol bridge_M2b=B.1   	; SORTIDA.Semi-bridge_b del motor_M2.
symbol PUJAR=C.3              ; ENTRADA. Boto de pujar.
symbol pujant=pinc.3          ; ENTRADA. Boto de pujar.
symbol BAIXAR=C.1             ; ENTRADA. Boto de baixar.
symbol baixant=pinc.1         ; ENTRADA. Boto de baixar.
symbol led_inferior=B.5       ; SORTIDA. Led emisor1.
symbol led_superior=B.4       ; SORTIDA. Led emisor2.
symbol fiCursa_inferior=B.2   ; ENTRADA. Fototransistor_1
symbol fiCursa_superior=B.3   ; ENTRADA. Fototransistor_2
symbol sensor=C.0             ; ENTRADA. Sensor infrarroig TSOP4838.
;DEFINICIO DE CONSTANTS DE PROGRAMA.
;DEFINICIO DE VARIABLES DE PROGRAMA
symbol llegit_lsb=b10    
;DISPOSSITIUS
config_PCA9555N_A:	  ; CONFIGURACIO DEL DEVICE_A (A,B,C,D,E,F,G,H. Maxim 8).
;PCA9555.DEFINICIO DE CONSTANTS
symbol adress_slave_A =$40; Direccio slave PCA9555N % 0100ABC(rw)(0X4E-0X4F).
symbol polport_0A=%00000000; Pol_laritat entrades port_0:0-no inv. 1-invertides.
symbol polport_1A=%00000000; Pol_laritat entrades port_1:0-no inv. 1-invertides.	
symbol confport_0A = %11111111; Configuracio port_0 1=entrada 0=sortida.
symbol confport_1A = %00000000; Configuracio port_1 1=entrada 0=sortida.
;PCA9555.DEFINICIONS DE VARIABLES Y INICIALITZACIONS.
; Localitzacio interna dels registres.
symbol @inPort_0A=$00
symbol @inPort_1A=$01
symbol @outPort_0A=$02
symbol @outPort_1A=$03
symbol @polPort_0A=$04
symbol @polPort_1A=$05
symbol @confPort_0A=$06
symbol @confPort_1A=$07
;PCA9555.FUNCIONS DE LECTURA I ESCRIPTURA EN EL SETUP INICIAL.
transfer_config_PCA9555N_A: ; transfereix configuracio anterior al PCA9555_A
i2cslave adress_slave_A, i2cslow, i2cbyte ; Peticionant bus I2C per PCA9555.
writei2c @polPort_0A,(polport_0A,polport_1A); Escriu la pol_laritat dels ports.
writei2c @confPort_0A,(confport_0A,confport_1A); Escriu la configuracio dels ports.
lectura_inicial_debug_A:       ; LECTURA DE LOS REGISTRES INTERNS PCA9555_A.
i2cslave adress_slave_A, i2cslow, i2cbyte   ; Peticionant bus I2C per PCA9555.
readi2c @inport_0A,(b0,b1)     ; Lectura 2 bytes pins d'entrada dels ports 0 i 1
readi2c @outport_0A,(b2,b3)    ; Lectura 2 bytes pins de sortida dels ports 0 i 1
readi2c @polPort_0A,(b4,b5)    ; Lectura 2 bytes pol_laridat dels ports 0 i 1
readi2c @confPort_0A,(b6,b7)   ; Lectura 2 bytes configuracio dels ports 0 i 1
; PROGRAMA REITERATIU
main:
i2cslave adress_slave_A, i2cslow, i2cbyte; Peticionant al bus I2C per PCA9555_A.
readi2c @inport_0A,(llegit_lsb)  ; Llegir entrada port 0 i desar en byte_llegit
writei2c @outport_1A,(llegit_lsb); Escriure byte_llegit en el port 1
pause 100                        ; Esperas 0'1 segons
debug                            ; Treure les dades pel monitor de l'editor
goto main                        ; Tornar-ho a fer.
;SUBRUTINES